/*
 * Copyright 2019. Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.android.apps.santatracker.dasherdancer

import android.annotation.SuppressLint
import android.graphics.Point
import androidx.annotation.DrawableRes
import java.util.HashMap

class ResourceOffsets {

    companion object {

        @SuppressLint("UseSparseArrays")
        private val offsets = HashMap<Int, Point>()

        init {
            offsets[R.drawable.elf_pinchout_0006] = Point(0, 0)
            offsets[R.drawable.snowman_swiperight0015] = Point(429, 221)
            offsets[R.drawable.reindeer_swipedown0018] = Point(365, 709)
            offsets[R.drawable.elf_shake_0006] = Point(318, 230)
            offsets[R.drawable.reindeer_swipeleft0002] = Point(341, 331)
            offsets[R.drawable.reindeer_pinchout0024] = Point(342, 337)
            offsets[R.drawable.snowman_swipeup0023] = Point(429, 220)
            offsets[R.drawable.snowman_pinchout0001] = Point(429, 221)
            offsets[R.drawable.snowman_pinchout0022] = Point(334, 310)
            offsets[R.drawable.reindeer_swipedown0008] = Point(365, 705)
            offsets[R.drawable.santa_pinchin0007] = Point(136, 218)
            offsets[R.drawable.snowman_swipedown0021] = Point(429, 250)
            offsets[R.drawable.santa_idle0021] = Point(415, 434)
            offsets[R.drawable.santa_pinchout20001] = Point(0, 0)
            offsets[R.drawable.reindeer_swipedown0009] = Point(376, 709)
            offsets[R.drawable.snowman_pinchin0001] = Point(429, 221)
            offsets[R.drawable.snowman_pinchout0005] = Point(360, 434)
            offsets[R.drawable.santa_swipeleft0017] = Point(147, 628)
            offsets[R.drawable.reindeer_swipeup0013] = Point(210, 37)
            offsets[R.drawable.snowman_pinchin0012] = Point(90, 806)
            offsets[R.drawable.santa_swipeleft0009] = Point(94, 606)
            offsets[R.drawable.snowman_swipeleft0007] = Point(429, 221)
            offsets[R.drawable.santa_idle0027] = Point(415, 432)
            offsets[R.drawable.snowman_tap0017] = Point(94, 221)
            offsets[R.drawable.santa_temp_tap01] = Point(415, 435)
            offsets[R.drawable.elf_swipeleft_0023] = Point(435, 358)
            offsets[R.drawable.reindeer_swipeleft0019] = Point(384, 347)
            offsets[R.drawable.snowman_pinchin0009] = Point(90, 422)
            offsets[R.drawable.elf_idle_0007] = Point(435, 437)
            offsets[R.drawable.snowman_idle0002] = Point(429, 220)
            offsets[R.drawable.reindeer_tap0008] = Point(342, 337)
            offsets[R.drawable.santa_swipe_right20005] = Point(350, 423)
            offsets[R.drawable.snowman_pinchout0003] = Point(395, 339)
            offsets[R.drawable.reindeer_pinchout0018] = Point(98, 37)
            offsets[R.drawable.snowman_swipeleft0004] = Point(429, 221)
            offsets[R.drawable.santa_idle0007] = Point(416, 430)
            offsets[R.drawable.snowman_swipeup0022] = Point(429, 219)
            offsets[R.drawable.santa_shake0005] = Point(229, 475)
            offsets[R.drawable.santa_swipeup0016] = Point(253, 221)
            offsets[R.drawable.snowman_tap0019] = Point(102, 221)
            offsets[R.drawable.santa_swipeup0023] = Point(427, 427)
            offsets[R.drawable.reindeer_pinchin0023] = Point(0, 0)
            offsets[R.drawable.snowman_swiperight0005] = Point(314, 221)
            offsets[R.drawable.elf_shake_0016] = Point(285, 309)
            offsets[R.drawable.reindeer_swipeup0016] = Point(240, 73)
            offsets[R.drawable.reindeer_swipedown0023] = Point(344, 351)
            offsets[R.drawable.reindeer_swipeup0010] = Point(210, 34)
            offsets[R.drawable.reindeer_swipedown0007] = Point(375, 595)
            offsets[R.drawable.reindeer_pinchin0003] = Point(0, 0)
            offsets[R.drawable.santa_shake0010] = Point(241, 468)
            offsets[R.drawable.snowman_swipeleft0011] = Point(429, 221)
            offsets[R.drawable.elf_tap_0018] = Point(435, 440)
            offsets[R.drawable.santa_swipeup0001] = Point(415, 435)
            offsets[R.drawable.elf_idle_0012] = Point(435, 436)
            offsets[R.drawable.snowman_swiperight0008] = Point(271, 221)
            offsets[R.drawable.elf_idle_0002] = Point(435, 440)
            offsets[R.drawable.snowman_pinchin0010] = Point(90, 513)
            offsets[R.drawable.elf_swiperight_0011] = Point(1073, 707)
            offsets[R.drawable.santa_shake0003] = Point(279, 476)
            offsets[R.drawable.elf_swipeleft_0012] = Point(294, 460)
            offsets[R.drawable.elf_tap_0017] = Point(429, 436)
            offsets[R.drawable.elf_pinchin_0008] = Point(520, 914)
            offsets[R.drawable.snowman_swipeup0003] = Point(429, 182)
            offsets[R.drawable.santa_swipeleft0013] = Point(429, 608)
            offsets[R.drawable.snowman_pinchout0020] = Point(237, 580)
            offsets[R.drawable.reindeer_shake0018] = Point(384, 13)
            offsets[R.drawable.snowman_swipeleft0001] = Point(429, 221)
            offsets[R.drawable.reindeer_swipedown0005] = Point(381, 451)
            offsets[R.drawable.reindeer_shake0021] = Point(384, 206)
            offsets[R.drawable.snowman_idle0020] = Point(429, 218)
            offsets[R.drawable.reindeer_tap0022] = Point(342, 337)
            offsets[R.drawable.snowman_swipedown0020] = Point(429, 279)
            offsets[R.drawable.snowman_shake0005] = Point(115, 0)
            offsets[R.drawable.snowman_swipeup0012] = Point(429, 21)
            offsets[R.drawable.santa_shake0013] = Point(363, 426)
            offsets[R.drawable.elf_pinchin_0001] = Point(435, 440)
            offsets[R.drawable.snowman_idle0022] = Point(429, 219)
            offsets[R.drawable.reindeer_swipeleft0021] = Point(370, 339)
            offsets[R.drawable.santa_pinchin0017] = Point(270, 435)
            offsets[R.drawable.elf_swiperight_0020] = Point(252, 504)
            offsets[R.drawable.elf_tap_0005] = Point(347, 380)
            offsets[R.drawable.snowman_pinchin0008] = Point(90, 367)
            offsets[R.drawable.snowman_idle0011] = Point(429, 217)
            offsets[R.drawable.reindeer_pinchin0018] = Point(0, 0)
            offsets[R.drawable.reindeer_swipeup0015] = Point(218, 46)
            offsets[R.drawable.santa_idle0032] = Point(416, 429)
            offsets[R.drawable.elf_pinchout_0020] = Point(106, 0)
            offsets[R.drawable.snowman_swipeup0007] = Point(427, 21)
            offsets[R.drawable.snowman_swipedown0013] = Point(429, 442)
            offsets[R.drawable.snowman_swipedown0018] = Point(429, 212)
            offsets[R.drawable.santa_pinchin0009] = Point(96, 154)
            offsets[R.drawable.snowman_pinchin0005] = Point(55, 0)
            offsets[R.drawable.santa_idle0017] = Point(415, 432)
            offsets[R.drawable.santa_swipeleft0007] = Point(165, 589)
            offsets[R.drawable.santa_idle0011] = Point(416, 429)
            offsets[R.drawable.reindeer_swipeleft0010] = Point(282, 280)
            offsets[R.drawable.reindeer_shake0013] = Point(383, 20)
            offsets[R.drawable.elf_shake_0023] = Point(435, 471)
            offsets[R.drawable.snowman_swipeup0008] = Point(429, 21)
            offsets[R.drawable.santa_swipedown0007] = Point(429, 635)
            offsets[R.drawable.reindeer_swipeleft0003] = Point(338, 311)
            offsets[R.drawable.santa_pinchout20004] = Point(0, 0)
            offsets[R.drawable.elf_swipeup_0011] = Point(378, 6)
            offsets[R.drawable.reindeer_tap0003] = Point(350, 341)
            offsets[R.drawable.santa_swipeleft0004] = Point(314, 530)
            offsets[R.drawable.elf_idle_0001] = Point(435, 440)
            offsets[R.drawable.elf_idle_0006] = Point(435, 437)
            offsets[R.drawable.elf_shake_0002] = Point(319, 369)
            offsets[R.drawable.elf_tap_0010] = Point(100, 262)
            offsets[R.drawable.reindeer_tap0020] = Point(342, 337)
            offsets[R.drawable.santa_tap0008] = Point(270, 596)
            offsets[R.drawable.reindeer_swipedown0013] = Point(360, 709)
            offsets[R.drawable.reindeer_swipeup0020] = Point(334, 368)
            offsets[R.drawable.snowman_swiperight0009] = Point(139, 221)
            offsets[R.drawable.elf_pinchin_0016] = Point(515, 127)
            offsets[R.drawable.reindeer_swiperight0012] = Point(0, 1069)
            offsets[R.drawable.reindeer_swipedown0017] = Point(363, 709)
            offsets[R.drawable.reindeer_swipeup0007] = Point(327, 105)
            offsets[R.drawable.elf_swipedown_0005] = Point(435, 454)
            offsets[R.drawable.reindeer_swiperight0008] = Point(205, 660)
            offsets[R.drawable.reindeer_shake0016] = Point(383, 17)
            offsets[R.drawable.reindeer_shake0008] = Point(384, 23)
            offsets[R.drawable.elf_swipeleft_0024] = Point(435, 363)
            offsets[R.drawable.santa_shake0015] = Point(332, 421)
            offsets[R.drawable.reindeer_swiperight0016] = Point(211, 335)
            offsets[R.drawable.santa_shake0014] = Point(367, 422)
            offsets[R.drawable.elf_swipeup_0003] = Point(386, 360)
            offsets[R.drawable.elf_tap_0011] = Point(81, 270)
            offsets[R.drawable.santa_temp_left01] = Point(415, 435)
            offsets[R.drawable.elf_swipedown_0018] = Point(435, 469)
            offsets[R.drawable.santa_idle0031] = Point(416, 430)
            offsets[R.drawable.elf_swipeup_0006] = Point(476, 165)
            offsets[R.drawable.elf_swiperight_0022] = Point(435, 459)
            offsets[R.drawable.snowman_swipeleft0003] = Point(429, 221)
            offsets[R.drawable.elf_swipeup_0005] = Point(475, 262)
            offsets[R.drawable.snowman_pinchout0006] = Point(342, 473)
            offsets[R.drawable.elf_swipeleft_0022] = Point(435, 352)
            offsets[R.drawable.elf_idle_0021] = Point(435, 438)
            offsets[R.drawable.santa_swipeup0003] = Point(423, 402)
            offsets[R.drawable.snowman_shake0001] = Point(393, 221)
            offsets[R.drawable.reindeer_swipeleft0007] = Point(301, 225)
            offsets[R.drawable.snowman_swipeleft0024] = Point(429, 221)
            offsets[R.drawable.snowman_tap0013] = Point(79, 221)
            offsets[R.drawable.santa_idle0029] = Point(415, 431)
            offsets[R.drawable.santa_idle0041] = Point(415, 433)
            offsets[R.drawable.snowman_swiperight0006] = Point(139, 221)
            offsets[R.drawable.reindeer_swipedown0010] = Point(383, 709)
            offsets[R.drawable.santa_shake0023] = Point(351, 426)
            offsets[R.drawable.santa_swipedown0021] = Point(0, 159)
            offsets[R.drawable.snowman_idle0018] = Point(429, 218)
            offsets[R.drawable.reindeer_swipeleft0013] = Point(301, 324)
            offsets[R.drawable.reindeer_pinchout0004] = Point(331, 324)
            offsets[R.drawable.elf_pinchin_0014] = Point(520, 134)
            offsets[R.drawable.snowman_pinchin0006] = Point(35, 64)
            offsets[R.drawable.santa_swipedown0023] = Point(0, 435)
            offsets[R.drawable.santa_shake0021] = Point(344, 421)
            offsets[R.drawable.santa_swipe_right20020] = Point(401, 435)
            offsets[R.drawable.snowman_shake0010] = Point(100, 0)
            offsets[R.drawable.elf_swipedown_0012] = Point(396, 611)
            offsets[R.drawable.elf_swipedown_0009] = Point(400, 535)
            offsets[R.drawable.reindeer_pinchout0015] = Point(84, 20)
            offsets[R.drawable.reindeer_shake0014] = Point(384, 30)
            offsets[R.drawable.elf_swipeleft_0013] = Point(269, 460)
            offsets[R.drawable.reindeer_shake0002] = Point(357, 301)
            offsets[R.drawable.snowman_swipeup0013] = Point(415, 21)
            offsets[R.drawable.santa_shake0022] = Point(279, 422)
            offsets[R.drawable.santa_shake0017] = Point(377, 420)
            offsets[R.drawable.santa_pinchin0005] = Point(215, 347)
            offsets[R.drawable.snowman_swipeleft0005] = Point(429, 221)
            offsets[R.drawable.elf_swipeup_0012] = Point(378, 119)
            offsets[R.drawable.santa_tap0011] = Point(270, 443)
            offsets[R.drawable.snowman_idle0009] = Point(429, 217)
            offsets[R.drawable.santa_tap0012] = Point(269, 443)
            offsets[R.drawable.snowman_swipeleft0006] = Point(429, 221)
            offsets[R.drawable.snowman_shake0002] = Point(130, 0)
            offsets[R.drawable.reindeer_swiperight0018] = Point(363, 338)
            offsets[R.drawable.santa_shake0019] = Point(341, 420)
            offsets[R.drawable.elf_shake_0021] = Point(228, 236)
            offsets[R.drawable.snowman_idle0017] = Point(429, 217)
            offsets[R.drawable.snowman_swiperight0007] = Point(191, 221)
            offsets[R.drawable.santa_swipedown0018] = Point(0, 0)
            offsets[R.drawable.snowman_tap0022] = Point(118, 221)
            offsets[R.drawable.snowman_swiperight0003] = Point(224, 221)
            offsets[R.drawable.elf_swipedown_0003] = Point(435, 414)
            offsets[R.drawable.snowman_swipeup0005] = Point(429, 70)
            offsets[R.drawable.snowman_swipedown0006] = Point(253, 447)
            offsets[R.drawable.snowman_pinchin0004] = Point(22, 0)
            offsets[R.drawable.snowman_swiperight0001] = Point(429, 221)
            offsets[R.drawable.santa_swipedown0010] = Point(429, 635)
            offsets[R.drawable.reindeer_swiperight0003] = Point(344, 337)
            offsets[R.drawable.elf_tap_0008] = Point(175, 254)
            offsets[R.drawable.snowman_swipeup0011] = Point(429, 21)
            offsets[R.drawable.santa_swipedown0006] = Point(429, 635)
            offsets[R.drawable.santa_idle0036] = Point(416, 429)
            offsets[R.drawable.snowman_swiperight0017] = Point(429, 221)
            offsets[R.drawable.snowman_swipedown0012] = Point(425, 350)
            offsets[R.drawable.santa_swipedown0005] = Point(429, 610)
            offsets[R.drawable.santa_idle0016] = Point(415, 432)
            offsets[R.drawable.snowman_shake0017] = Point(72, 0)
            offsets[R.drawable.elf_pinchin_0024] = Point(520, 518)
            offsets[R.drawable.snowman_swipedown0007] = Point(226, 419)
            offsets[R.drawable.reindeer_pinchout0021] = Point(183, 142)
            offsets[R.drawable.reindeer_pinchin0022] = Point(0, 0)
            offsets[R.drawable.santa_swipedown0008] = Point(429, 635)
            offsets[R.drawable.elf_tap_0015] = Point(382, 398)
            offsets[R.drawable.reindeer_pinchout0003] = Point(339, 334)
            offsets[R.drawable.reindeer_swipeleft0022] = Point(353, 338)
            offsets[R.drawable.elf_shake_0011] = Point(343, 183)
            offsets[R.drawable.elf_swiperight_0002] = Point(423, 441)
            offsets[R.drawable.reindeer_swipeup0006] = Point(353, 154)
            offsets[R.drawable.elf_tap_0016] = Point(412, 422)
            offsets[R.drawable.santa_temp_shake01] = Point(415, 435)
            offsets[R.drawable.elf_swipeup_0021] = Point(435, 480)
            offsets[R.drawable.elf_idle_0009] = Point(435, 437)
            offsets[R.drawable.elf_swipedown_0016] = Point(433, 561)
            offsets[R.drawable.santa_pinchout20006] = Point(0, 0)
            offsets[R.drawable.santa_pinchout20020] = Point(0, 0)
            offsets[R.drawable.reindeer_pinchout0007] = Point(276, 255)
            offsets[R.drawable.snowman_idle0003] = Point(429, 219)
            offsets[R.drawable.elf_swipeleft_0019] = Point(432, 393)
            offsets[R.drawable.reindeer_pinchout0016] = Point(82, 17)
            offsets[R.drawable.santa_idle0040] = Point(415, 432)
            offsets[R.drawable.elf_swiperight_0017] = Point(0, 606)
            offsets[R.drawable.snowman_swiperight0011] = Point(330, 221)
            offsets[R.drawable.santa_idle0001] = Point(415, 435)
            offsets[R.drawable.snowman_tap0004] = Point(245, 227)
            offsets[R.drawable.elf_tap_0013] = Point(286, 324)
            offsets[R.drawable.elf_shake_0012] = Point(318, 233)
            offsets[R.drawable.snowman_swipedown0016] = Point(422, 13)
            offsets[R.drawable.reindeer_pinchin0004] = Point(0, 0)
            offsets[R.drawable.santa_swipeup0005] = Point(429, 375)
            offsets[R.drawable.snowman_shake0003] = Point(126, 21)
            offsets[R.drawable.elf_pinchout_0004] = Point(0, 0)
            offsets[R.drawable.reindeer_swipedown0004] = Point(364, 401)
            offsets[R.drawable.reindeer_pinchout0023] = Point(281, 262)
            offsets[R.drawable.santa_swipeleft0018] = Point(216, 579)
            offsets[R.drawable.reindeer_shake0004] = Point(383, 13)
            offsets[R.drawable.santa_swipe_right20001] = Point(415, 435)
            offsets[R.drawable.santa_swipe_right20021] = Point(389, 435)
            offsets[R.drawable.santa_swipeleft0014] = Point(429, 508)
            offsets[R.drawable.elf_shake_0018] = Point(279, 233)
            offsets[R.drawable.santa_idle0003] = Point(415, 433)
            offsets[R.drawable.santa_swipeup0018] = Point(317, 317)
            offsets[R.drawable.elf_idle_0010] = Point(435, 436)
            offsets[R.drawable.snowman_pinchin0024] = Point(401, 220)
            offsets[R.drawable.snowman_swiperight0016] = Point(429, 221)
            offsets[R.drawable.snowman_pinchin0007] = Point(35, 64)
            offsets[R.drawable.reindeer_pinchin0020] = Point(0, 0)
            offsets[R.drawable.elf_swipedown_0015] = Point(400, 605)
            offsets[R.drawable.elf_tap_0014] = Point(337, 366)
            offsets[R.drawable.elf_tap_0006] = Point(290, 333)
            offsets[R.drawable.elf_swiperight_0023] = Point(423, 440)
            offsets[R.drawable.santa_swipe_right20023] = Point(415, 435)
            offsets[R.drawable.snowman_tap0002] = Point(381, 227)
            offsets[R.drawable.santa_swipedown0022] = Point(0, 414)
            offsets[R.drawable.santa_swipe_right20017] = Point(415, 385)
            offsets[R.drawable.elf_pinchin_0012] = Point(519, 270)
            offsets[R.drawable.santa_idle0008] = Point(416, 430)
            offsets[R.drawable.snowman_idle0001] = Point(429, 221)
            offsets[R.drawable.reindeer_pinchout0010] = Point(177, 135)
            offsets[R.drawable.reindeer_swipeup0019] = Point(349, 266)
            offsets[R.drawable.santa_tap0022] = Point(358, 435)
            offsets[R.drawable.santa_swipeup0012] = Point(417, 213)
            offsets[R.drawable.snowman_idle0019] = Point(429, 218)
            offsets[R.drawable.elf_swipedown_0023] = Point(435, 460)
            offsets[R.drawable.elf_pinchin_0025] = Point(476, 280)
            offsets[R.drawable.santa_swipe_right20009] = Point(332, 416)
            offsets[R.drawable.santa_idle0038] = Point(415, 431)
            offsets[R.drawable.snowman_pinchout0021] = Point(285, 423)
            offsets[R.drawable.santa_swipeup0022] = Point(420, 438)
            offsets[R.drawable.elf_pinchin_0007] = Point(497, 828)
            offsets[R.drawable.reindeer_shake0023] = Point(342, 346)
            offsets[R.drawable.snowman_idle0023] = Point(429, 220)
            offsets[R.drawable.snowman_swiperight0012] = Point(399, 221)
            offsets[R.drawable.reindeer_pinchout0017] = Point(86, 22)
            offsets[R.drawable.reindeer_swipedown0001] = Point(342, 337)
            offsets[R.drawable.snowman_pinchin0021] = Point(182, 191)
            offsets[R.drawable.snowman_swipeup0020] = Point(429, 221)
            offsets[R.drawable.reindeer_shake0019] = Point(384, 34)
            offsets[R.drawable.elf_swipeleft_0009] = Point(391, 460)
            offsets[R.drawable.snowman_tap0016] = Point(90, 221)
            offsets[R.drawable.elf_shake_0004] = Point(228, 236)
            offsets[R.drawable.snowman_tap0020] = Point(105, 221)
            offsets[R.drawable.elf_pinchout_0022] = Point(464, 489)
            offsets[R.drawable.santa_swipedown0011] = Point(345, 613)
            offsets[R.drawable.elf_pinchin_0029] = Point(404, 450)
            offsets[R.drawable.elf_shake_0013] = Point(201, 285)
            offsets[R.drawable.santa_swipeup0007] = Point(429, 304)
            offsets[R.drawable.snowman_idle0016] = Point(429, 217)
            offsets[R.drawable.santa_swipe_right20010] = Point(312, 437)
            offsets[R.drawable.reindeer_swipeup0018] = Point(329, 183)
            offsets[R.drawable.reindeer_tap0010] = Point(342, 337)
            offsets[R.drawable.elf_swipedown_0001] = Point(435, 440)
            offsets[R.drawable.elf_swipeup_0020] = Point(404, 450)
            offsets[R.drawable.elf_pinchout_0023] = Point(459, 480)
            offsets[R.drawable.santa_pinchin0018] = Point(235, 505)
            offsets[R.drawable.reindeer_pinchin0019] = Point(0, 0)
            offsets[R.drawable.santa_shake0006] = Point(245, 474)
            offsets[R.drawable.snowman_shake0019] = Point(74, 0)
            offsets[R.drawable.santa_idle0019] = Point(415, 434)
            offsets[R.drawable.snowman_swipedown0011] = Point(394, 381)
            offsets[R.drawable.snowman_pinchin0020] = Point(167, 189)
            offsets[R.drawable.santa_idle0043] = Point(415, 434)
            offsets[R.drawable.snowman_swipeleft0013] = Point(415, 221)
            offsets[R.drawable.reindeer_swipeup0023] = Point(193, 338)
            offsets[R.drawable.elf_swiperight_0003] = Point(435, 425)
            offsets[R.drawable.reindeer_swipedown0014] = Point(343, 709)
            offsets[R.drawable.santa_swipeleft0020] = Point(351, 467)
            offsets[R.drawable.snowman_swipeleft0023] = Point(429, 221)
            offsets[R.drawable.reindeer_swipeup0021] = Point(268, 354)
            offsets[R.drawable.snowman_tap0009] = Point(79, 221)
            offsets[R.drawable.elf_shake_0009] = Point(201, 285)
            offsets[R.drawable.santa_swipeleft0003] = Point(374, 516)
            offsets[R.drawable.snowman_swipeleft0022] = Point(429, 221)
            offsets[R.drawable.santa_tap0015] = Point(270, 412)
            offsets[R.drawable.snowman_pinchout0002] = Point(412, 283)
            offsets[R.drawable.elf_swipedown_0010] = Point(397, 556)
            offsets[R.drawable.elf_pinchin_0011] = Point(521, 426)
            offsets[R.drawable.reindeer_swipedown0012] = Point(378, 709)
            offsets[R.drawable.santa_pinchin0002] = Point(358, 435)
            offsets[R.drawable.reindeer_tap0004] = Point(346, 339)
            offsets[R.drawable.snowman_shake0015] = Point(83, 0)
            offsets[R.drawable.santa_shake0016] = Point(322, 420)
            offsets[R.drawable.snowman_pinchin0014] = Point(90, 1245)
            offsets[R.drawable.reindeer_swiperight0023] = Point(330, 341)
            offsets[R.drawable.santa_pinchin0019] = Point(224, 529)
            offsets[R.drawable.reindeer_swipeleft0018] = Point(384, 355)
            offsets[R.drawable.reindeer_shake0015] = Point(384, 23)
            offsets[R.drawable.snowman_pinchin0011] = Point(90, 641)
            offsets[R.drawable.santa_swipe_right20011] = Point(412, 394)
            offsets[R.drawable.santa_pinchin0004] = Point(270, 435)
            offsets[R.drawable.snowman_shake0021] = Point(68, 11)
            offsets[R.drawable.reindeer_swipeleft0012] = Point(291, 300)
            offsets[R.drawable.santa_swipeup0006] = Point(429, 334)
            offsets[R.drawable.reindeer_pinchout0006] = Point(299, 285)
            offsets[R.drawable.santa_pinchin0001] = Point(415, 435)
            offsets[R.drawable.santa_swipeup0020] = Point(425, 462)
            offsets[R.drawable.elf_swipeleft_0007] = Point(362, 460)
            offsets[R.drawable.snowman_tap0015] = Point(87, 221)
            offsets[R.drawable.elf_swiperight_0007] = Point(506, 517)
            offsets[R.drawable.elf_swipeup_0016] = Point(476, 200)
            offsets[R.drawable.elf_swipeleft_0020] = Point(435, 389)
            offsets[R.drawable.santa_swipedown0009] = Point(429, 635)
            offsets[R.drawable.santa_swipe_right20002] = Point(420, 435)
            offsets[R.drawable.elf_swipeleft_0015] = Point(369, 460)
            offsets[R.drawable.elf_swipeleft_0002] = Point(414, 441)
            offsets[R.drawable.elf_swipeleft_0008] = Point(393, 460)
            offsets[R.drawable.santa_tap0019] = Point(270, 423)
            offsets[R.drawable.elf_pinchout_0007] = Point(0, 0)
            offsets[R.drawable.snowman_swiperight0018] = Point(429, 221)
            offsets[R.drawable.elf_pinchin_0006] = Point(487, 762)
            offsets[R.drawable.snowman_pinchout0011] = Point(255, 577)
            offsets[R.drawable.snowman_swiperight0022] = Point(417, 221)
            offsets[R.drawable.reindeer_swiperight0021] = Point(325, 361)
            offsets[R.drawable.snowman_idle0007] = Point(429, 217)
            offsets[R.drawable.santa_swipedown0013] = Point(266, 0)
            offsets[R.drawable.santa_pinchout20002] = Point(0, 0)
            offsets[R.drawable.santa_swipeup0019] = Point(422, 428)
            offsets[R.drawable.snowman_swipeleft0016] = Point(429, 221)
            offsets[R.drawable.elf_swipeup_0004] = Point(435, 200)
            offsets[R.drawable.santa_swipeleft0006] = Point(209, 565)
            offsets[R.drawable.santa_idle0005] = Point(415, 431)
            offsets[R.drawable.reindeer_swipeup0014] = Point(210, 37)
            offsets[R.drawable.elf_shake_0010] = Point(285, 309)
            offsets[R.drawable.reindeer_swipeleft0008] = Point(290, 260)
            offsets[R.drawable.snowman_swipeup0016] = Point(219, 21)
            offsets[R.drawable.reindeer_swipeup0003] = Point(342, 275)
            offsets[R.drawable.reindeer_swiperight0009] = Point(121, 685)
            offsets[R.drawable.reindeer_swiperight0017] = Point(249, 332)
            offsets[R.drawable.elf_swipeup_0015] = Point(476, 311)
            offsets[R.drawable.elf_swipeup_0013] = Point(397, 259)
            offsets[R.drawable.santa_shake0024] = Point(355, 435)
            offsets[R.drawable.santa_shake0002] = Point(328, 456)
            offsets[R.drawable.reindeer_swipeleft0004] = Point(333, 279)
            offsets[R.drawable.snowman_shake0016] = Point(76, 0)
            offsets[R.drawable.santa_swipedown0014] = Point(262, 0)
            offsets[R.drawable.reindeer_swipedown0019] = Point(384, 601)
            offsets[R.drawable.elf_pinchin_0031] = Point(435, 458)
            offsets[R.drawable.santa_idle0046] = Point(415, 435)
            offsets[R.drawable.elf_pinchin_0020] = Point(520, 898)
            offsets[R.drawable.santa_tap0005] = Point(270, 509)
            offsets[R.drawable.santa_idle0009] = Point(416, 429)
            offsets[R.drawable.santa_temp_down01] = Point(415, 435)
            offsets[R.drawable.elf_pinchout_0019] = Point(50, 0)
            offsets[R.drawable.snowman_tap0006] = Point(146, 221)
            offsets[R.drawable.elf_swiperight_0021] = Point(427, 451)
            offsets[R.drawable.santa_swipeup0021] = Point(399, 471)
            offsets[R.drawable.elf_idle_0019] = Point(435, 438)
            offsets[R.drawable.elf_swiperight_0010] = Point(888, 568)
            offsets[R.drawable.reindeer_swipedown0021] = Point(371, 437)
            offsets[R.drawable.snowman_swipeleft0019] = Point(429, 221)
            offsets[R.drawable.reindeer_shake0020] = Point(384, 99)
            offsets[R.drawable.snowman_tap0008] = Point(79, 221)
            offsets[R.drawable.santa_idle0020] = Point(415, 434)
            offsets[R.drawable.snowman_tap0024] = Point(429, 221)
            offsets[R.drawable.snowman_swipeup0004] = Point(429, 133)
            offsets[R.drawable.reindeer_swipeleft0001] = Point(342, 337)
            offsets[R.drawable.snowman_shake0007] = Point(108, 0)
            offsets[R.drawable.santa_swipeleft0015] = Point(415, 416)
            offsets[R.drawable.elf_tap_0012] = Point(221, 272)
            offsets[R.drawable.elf_pinchout_0003] = Point(250, 0)
            offsets[R.drawable.reindeer_shake0022] = Point(342, 357)
            offsets[R.drawable.reindeer_shake0005] = Point(384, 13)
            offsets[R.drawable.snowman_swipeleft0021] = Point(429, 221)
            offsets[R.drawable.reindeer_swipedown0006] = Point(384, 516)
            offsets[R.drawable.elf_swiperight_0018] = Point(0, 538)
            offsets[R.drawable.elf_idle_0008] = Point(435, 437)
            offsets[R.drawable.reindeer_swipeup0017] = Point(277, 119)
            offsets[R.drawable.elf_pinchin_0022] = Point(513, 738)
            offsets[R.drawable.elf_swipeup_0018] = Point(454, 400)
            offsets[R.drawable.santa_swipeup0010] = Point(429, 266)
            offsets[R.drawable.snowman_pinchout0009] = Point(290, 553)
            offsets[R.drawable.elf_pinchin_0010] = Point(521, 653)
            offsets[R.drawable.snowman_tap0011] = Point(79, 221)
            offsets[R.drawable.elf_swipeleft_0006] = Point(330, 460)
            offsets[R.drawable.elf_swipeleft_0004] = Point(372, 441)
            offsets[R.drawable.snowman_swiperight0020] = Point(429, 221)
            offsets[R.drawable.reindeer_swiperight0015] = Point(0, 335)
            offsets[R.drawable.snowman_shake0008] = Point(110, 0)
            offsets[R.drawable.elf_swipeup_0009] = Point(357, 152)
            offsets[R.drawable.elf_swipeup_0002] = Point(386, 400)
            offsets[R.drawable.snowman_swipedown0010] = Point(335, 435)
            offsets[R.drawable.santa_swipe_right20015] = Point(415, 353)
            offsets[R.drawable.reindeer_swipeleft0023] = Point(344, 337)
            offsets[R.drawable.santa_pinchout20003] = Point(0, 0)
            offsets[R.drawable.snowman_swiperight0013] = Point(429, 221)
            offsets[R.drawable.snowman_swipedown0015] = Point(429, 261)
            offsets[R.drawable.snowman_swipeup0014] = Point(346, 21)
            offsets[R.drawable.snowman_swipedown0008] = Point(207, 344)
            offsets[R.drawable.reindeer_pinchout0012] = Point(124, 69)
            offsets[R.drawable.santa_temp_zoom_in01] = Point(415, 435)
            offsets[R.drawable.reindeer_pinchin0021] = Point(0, 0)
            offsets[R.drawable.santa_tap0017] = Point(270, 423)
            offsets[R.drawable.snowman_shake0006] = Point(110, 0)
            offsets[R.drawable.reindeer_tap0006] = Point(342, 337)
            offsets[R.drawable.elf_idle_0024] = Point(435, 440)
            offsets[R.drawable.santa_swipeleft0005] = Point(258, 546)
            offsets[R.drawable.elf_pinchin_0027] = Point(459, 400)
            offsets[R.drawable.reindeer_tap0005] = Point(342, 337)
            offsets[R.drawable.elf_swipedown_0020] = Point(435, 470)
            offsets[R.drawable.elf_idle_0011] = Point(435, 436)
            offsets[R.drawable.santa_swipedown0001] = Point(415, 435)
            offsets[R.drawable.elf_shake_0008] = Point(318, 362)
            offsets[R.drawable.reindeer_pinchout0022] = Point(228, 197)
            offsets[R.drawable.reindeer_pinchout0014] = Point(92, 30)
            offsets[R.drawable.snowman_swipedown0002] = Point(400, 266)
            offsets[R.drawable.reindeer_swiperight0001] = Point(342, 337)
            offsets[R.drawable.santa_swipedown0019] = Point(0, 0)
            offsets[R.drawable.santa_swipeleft0024] = Point(429, 424)
            offsets[R.drawable.reindeer_swiperight0005] = Point(354, 337)
            offsets[R.drawable.santa_pinchout20023] = Point(0, 0)
            offsets[R.drawable.snowman_swipeup0002] = Point(429, 211)
            offsets[R.drawable.santa_idle0022] = Point(415, 435)
            offsets[R.drawable.elf_swipeleft_0010] = Point(317, 460)
            offsets[R.drawable.snowman_tap0007] = Point(95, 221)
            offsets[R.drawable.santa_swipedown0002] = Point(358, 435)
            offsets[R.drawable.santa_idle0018] = Point(415, 433)
            offsets[R.drawable.reindeer_shake0010] = Point(383, 13)
            offsets[R.drawable.santa_tap0014] = Point(270, 320)
            offsets[R.drawable.santa_shake0020] = Point(386, 420)
            offsets[R.drawable.snowman_swipeup0017] = Point(231, 33)
            offsets[R.drawable.elf_swipeup_0023] = Point(435, 445)
            offsets[R.drawable.elf_tap_0007] = Point(221, 272)
            offsets[R.drawable.snowman_idle0021] = Point(429, 219)
            offsets[R.drawable.elf_pinchin_0013] = Point(519, 169)
            offsets[R.drawable.elf_pinchin_0018] = Point(506, 385)
            offsets[R.drawable.santa_pinchin0006] = Point(171, 275)
            offsets[R.drawable.reindeer_swipedown0015] = Point(349, 709)
            offsets[R.drawable.santa_swipe_right20007] = Point(341, 418)
            offsets[R.drawable.reindeer_swiperight0022] = Point(304, 370)
            offsets[R.drawable.santa_swipeleft0002] = Point(398, 476)
            offsets[R.drawable.santa_swipedown0004] = Point(340, 535)
            offsets[R.drawable.reindeer_swipedown0016] = Point(357, 709)
            offsets[R.drawable.snowman_swipedown0005] = Point(285, 401)
            offsets[R.drawable.reindeer_tap0009] = Point(342, 337)
            offsets[R.drawable.snowman_swipeup0021] = Point(429, 220)
            offsets[R.drawable.elf_swipedown_0006] = Point(435, 475)
            offsets[R.drawable.reindeer_swipeleft0011] = Point(284, 285)
            offsets[R.drawable.snowman_shake0014] = Point(87, 3)
            offsets[R.drawable.snowman_idle0006] = Point(429, 218)
            offsets[R.drawable.santa_swipe_right20004] = Point(350, 428)
            offsets[R.drawable.reindeer_swipeleft0005] = Point(326, 235)
            offsets[R.drawable.snowman_idle0004] = Point(429, 219)
            offsets[R.drawable.elf_shake_0001] = Point(435, 440)
            offsets[R.drawable.elf_swipedown_0022] = Point(435, 463)
            offsets[R.drawable.elf_swipeup_0017] = Point(456, 380)
            offsets[R.drawable.snowman_pinchout0013] = Point(237, 580)
            offsets[R.drawable.santa_swipeleft0016] = Point(299, 540)
            offsets[R.drawable.snowman_pinchout0010] = Point(272, 568)
            offsets[R.drawable.snowman_tap0003] = Point(277, 248)
            offsets[R.drawable.santa_shake0001] = Point(355, 435)
            offsets[R.drawable.elf_swiperight_0009] = Point(769, 641)
            offsets[R.drawable.santa_swipe_right20016] = Point(415, 370)
            offsets[R.drawable.santa_idle0010] = Point(416, 429)
            offsets[R.drawable.elf_swiperight_0006] = Point(441, 476)
            offsets[R.drawable.elf_swipeup_0007] = Point(492, 165)
            offsets[R.drawable.elf_idle_0017] = Point(435, 437)
            offsets[R.drawable.santa_swipeleft0008] = Point(127, 618)
            offsets[R.drawable.santa_pinchout20021] = Point(0, 0)
            offsets[R.drawable.santa_idle0013] = Point(416, 429)
            offsets[R.drawable.snowman_swipedown0009] = Point(266, 281)
            offsets[R.drawable.snowman_swipedown0014] = Point(429, 411)
            offsets[R.drawable.elf_tap_0003] = Point(427, 434)
            offsets[R.drawable.snowman_pinchin0003] = Point(193, 109)
            offsets[R.drawable.santa_swipeleft0012] = Point(429, 558)
            offsets[R.drawable.snowman_idle0005] = Point(429, 218)
            offsets[R.drawable.snowman_idle0010] = Point(429, 217)
            offsets[R.drawable.santa_swipedown0016] = Point(429, 402)
            offsets[R.drawable.reindeer_swiperight0010] = Point(61, 1026)
            offsets[R.drawable.snowman_pinchout0012] = Point(237, 580)
            offsets[R.drawable.elf_idle_0005] = Point(435, 438)
            offsets[R.drawable.reindeer_tap0002] = Point(346, 339)
            offsets[R.drawable.elf_tap_0004] = Point(401, 413)
            offsets[R.drawable.santa_idle0030] = Point(416, 430)
            offsets[R.drawable.elf_pinchin_0023] = Point(521, 583)
            offsets[R.drawable.reindeer_pinchin0001] = Point(0, 0)
            offsets[R.drawable.reindeer_pinchout0009] = Point(212, 177)
            offsets[R.drawable.reindeer_pinchout0001] = Point(342, 337)
            offsets[R.drawable.santa_swipeleft0022] = Point(398, 448)
            offsets[R.drawable.reindeer_swiperight0006] = Point(363, 644)
            offsets[R.drawable.snowman_tap0010] = Point(79, 221)
            offsets[R.drawable.elf_pinchout_0024] = Point(444, 455)
            offsets[R.drawable.elf_pinchout_0001] = Point(435, 440)
            offsets[R.drawable.santa_swipe_right20003] = Point(347, 435)
            offsets[R.drawable.snowman_swipeleft0020] = Point(429, 221)
            offsets[R.drawable.reindeer_shake0024] = Point(342, 339)
            offsets[R.drawable.snowman_pinchin0022] = Point(226, 197)
            offsets[R.drawable.snowman_shake0020] = Point(73, 5)
            offsets[R.drawable.santa_tap0013] = Point(270, 412)
            offsets[R.drawable.elf_swipeleft_0003] = Point(393, 440)
            offsets[R.drawable.snowman_shake0024] = Point(382, 216)
            offsets[R.drawable.santa_tap0007] = Point(270, 586)
            offsets[R.drawable.snowman_shake0013] = Point(88, 0)
            offsets[R.drawable.snowman_tap0021] = Point(118, 221)
            offsets[R.drawable.elf_swipeup_0010] = Point(378, 84)
            offsets[R.drawable.elf_swipedown_0011] = Point(397, 560)
            offsets[R.drawable.snowman_pinchin0023] = Point(299, 207)
            offsets[R.drawable.elf_swiperight_0019] = Point(83, 515)
            offsets[R.drawable.reindeer_swipeup0008] = Point(210, 47)
            offsets[R.drawable.snowman_tap0012] = Point(79, 221)
            offsets[R.drawable.reindeer_swipeleft0015] = Point(338, 400)
            offsets[R.drawable.elf_swiperight_0013] = Point(0, 730)
            offsets[R.drawable.santa_idle0028] = Point(415, 431)
            offsets[R.drawable.santa_pinchin0010] = Point(91, 146)
            offsets[R.drawable.snowman_pinchin0002] = Point(374, 193)
            offsets[R.drawable.elf_swipeup_0014] = Point(468, 315)
            offsets[R.drawable.reindeer_swipeleft0020] = Point(384, 342)
            offsets[R.drawable.elf_pinchin_0003] = Point(460, 584)
            offsets[R.drawable.elf_pinchin_0021] = Point(500, 990)
            offsets[R.drawable.reindeer_swipeleft0014] = Point(317, 357)
            offsets[R.drawable.reindeer_tap0019] = Point(342, 337)
            offsets[R.drawable.reindeer_swipeleft0017] = Point(376, 371)
            offsets[R.drawable.santa_tap0010] = Point(270, 536)
            offsets[R.drawable.reindeer_swiperight0019] = Point(384, 389)
            offsets[R.drawable.elf_shake_0019] = Point(231, 285)
            offsets[R.drawable.snowman_pinchin0016] = Point(167, 913)
            offsets[R.drawable.elf_swipeleft_0001] = Point(435, 440)
            offsets[R.drawable.snowman_shake0022] = Point(64, 16)
            offsets[R.drawable.santa_shake0012] = Point(355, 435)
            offsets[R.drawable.santa_pinchin0013] = Point(136, 219)
            offsets[R.drawable.elf_swipeleft_0014] = Point(395, 460)
            offsets[R.drawable.santa_swipeup0002] = Point(418, 418)
            offsets[R.drawable.elf_swipedown_0008] = Point(434, 515)
            offsets[R.drawable.elf_swipedown_0007] = Point(435, 495)
            offsets[R.drawable.snowman_tap0001] = Point(429, 221)
            offsets[R.drawable.snowman_pinchout0007] = Point(325, 506)
            offsets[R.drawable.santa_idle0037] = Point(416, 430)
            offsets[R.drawable.santa_swipedown0012] = Point(265, 264)
            offsets[R.drawable.santa_idle0015] = Point(415, 431)
            offsets[R.drawable.santa_pinchout20019] = Point(0, 0)
            offsets[R.drawable.reindeer_swiperight0014] = Point(0, 335)
            offsets[R.drawable.reindeer_swipeleft0006] = Point(318, 177)
            offsets[R.drawable.santa_swipe_right20022] = Point(415, 435)
            offsets[R.drawable.santa_swipedown0020] = Point(0, 0)
            offsets[R.drawable.reindeer_tap0001] = Point(342, 337)
            offsets[R.drawable.santa_swipeup0013] = Point(312, 193)
            offsets[R.drawable.reindeer_pinchout0005] = Point(318, 308)
            offsets[R.drawable.santa_shake0008] = Point(255, 477)
            offsets[R.drawable.reindeer_swipeleft0016] = Point(353, 389)
            offsets[R.drawable.snowman_swipeup0006] = Point(429, 33)
            offsets[R.drawable.snowman_shake0012] = Point(91, 0)
            offsets[R.drawable.elf_shake_0017] = Point(201, 183)
            offsets[R.drawable.reindeer_swipedown0020] = Point(384, 510)
            offsets[R.drawable.santa_idle0042] = Point(415, 433)
            offsets[R.drawable.reindeer_pinchout0002] = Point(342, 337)
            offsets[R.drawable.santa_idle0044] = Point(415, 434)
            offsets[R.drawable.santa_idle0006] = Point(415, 431)
            offsets[R.drawable.santa_swipeleft0019] = Point(429, 428)
            offsets[R.drawable.reindeer_swipedown0011] = Point(384, 709)
            offsets[R.drawable.elf_shake_0005] = Point(201, 183)
            offsets[R.drawable.snowman_swipeleft0010] = Point(429, 221)
            offsets[R.drawable.reindeer_shake0006] = Point(384, 14)
            offsets[R.drawable.santa_tap0006] = Point(270, 557)
            offsets[R.drawable.elf_pinchin_0002] = Point(447, 512)
            offsets[R.drawable.elf_swiperight_0005] = Point(407, 458)
            offsets[R.drawable.santa_idle0039] = Point(415, 431)
            offsets[R.drawable.elf_swipeup_0019] = Point(434, 440)
            offsets[R.drawable.elf_swipeleft_0011] = Point(295, 460)
            offsets[R.drawable.reindeer_pinchout0008] = Point(246, 219)
            offsets[R.drawable.snowman_shake0023] = Point(382, 216)
            offsets[R.drawable.snowman_swiperight0021] = Point(429, 221)
            offsets[R.drawable.elf_pinchin_0019] = Point(520, 618)
            offsets[R.drawable.snowman_shake0004] = Point(122, 0)
            offsets[R.drawable.reindeer_pinchout0011] = Point(148, 99)
            offsets[R.drawable.santa_swipe_right20014] = Point(416, 340)
            offsets[R.drawable.elf_pinchin_0015] = Point(515, 95)
            offsets[R.drawable.santa_idle0002] = Point(415, 434)
            offsets[R.drawable.santa_pinchout20007] = Point(0, 0)
            offsets[R.drawable.santa_pinchin0014] = Point(170, 275)
            offsets[R.drawable.santa_swipedown0003] = Point(340, 460)
            offsets[R.drawable.snowman_pinchout0024] = Point(429, 221)
            offsets[R.drawable.santa_shake0009] = Point(243, 477)
            offsets[R.drawable.elf_tap_0002] = Point(435, 440)
            offsets[R.drawable.santa_swipeleft0023] = Point(429, 429)
            offsets[R.drawable.elf_shake_0015] = Point(263, 285)
            offsets[R.drawable.santa_swipe_right20008] = Point(336, 417)
            offsets[R.drawable.elf_shake_0020] = Point(324, 362)
            offsets[R.drawable.elf_shake_0003] = Point(176, 324)
            offsets[R.drawable.reindeer_swipeup0011] = Point(210, 34)
            offsets[R.drawable.santa_tap0016] = Point(270, 443)
            offsets[R.drawable.elf_swipeleft_0005] = Point(351, 460)
            offsets[R.drawable.elf_swipeup_0022] = Point(435, 458)
            offsets[R.drawable.snowman_swipeleft0009] = Point(429, 221)
            offsets[R.drawable.santa_swipeup0014] = Point(311, 178)
            offsets[R.drawable.elf_pinchin_0026] = Point(467, 340)
            offsets[R.drawable.elf_swipedown_0017] = Point(435, 470)
            offsets[R.drawable.santa_idle0012] = Point(416, 429)
            offsets[R.drawable.reindeer_swipedown0003] = Point(352, 366)
            offsets[R.drawable.santa_swipeleft0021] = Point(270, 462)
            offsets[R.drawable.santa_pinchout20018] = Point(0, 0)
            offsets[R.drawable.reindeer_swipeup0022] = Point(221, 344)
            offsets[R.drawable.snowman_swiperight0019] = Point(429, 221)
            offsets[R.drawable.reindeer_pinchout0013] = Point(106, 46)
            offsets[R.drawable.snowman_swipedown0003] = Point(359, 311)
            offsets[R.drawable.elf_swiperight_0014] = Point(0, 768)
            offsets[R.drawable.snowman_tap0005] = Point(213, 221)
            offsets[R.drawable.snowman_swiperight0023] = Point(429, 221)
            offsets[R.drawable.reindeer_shake0007] = Point(383, 15)
            offsets[R.drawable.elf_swiperight_0012] = Point(1280 / 2, 1280 / 2)
            offsets[R.drawable.snowman_pinchin0018] = Point(167, 370)
            offsets[R.drawable.santa_idle0045] = Point(415, 434)
            offsets[R.drawable.santa_swipeup0004] = Point(426, 385)
            offsets[R.drawable.elf_swipeleft_0021] = Point(435, 375)
            offsets[R.drawable.reindeer_swiperight0013] = Point(0, 569)
            offsets[R.drawable.reindeer_swiperight0024] = Point(342, 337)
            offsets[R.drawable.reindeer_swipeleft0024] = Point(342, 337)
            offsets[R.drawable.elf_idle_0004] = Point(435, 438)
            offsets[R.drawable.snowman_tap0014] = Point(83, 221)
            offsets[R.drawable.reindeer_pinchin0005] = Point(0, 0)
            offsets[R.drawable.santa_shake0011] = Point(326, 453)
            offsets[R.drawable.santa_swipedown0015] = Point(257, 0)
            offsets[R.drawable.reindeer_swipeup0012] = Point(210, 35)
            offsets[R.drawable.snowman_swipedown0004] = Point(320, 356)
            offsets[R.drawable.reindeer_pinchin0002] = Point(0, 0)
            offsets[R.drawable.santa_idle0033] = Point(416, 429)
            offsets[R.drawable.elf_pinchout_0002] = Point(376, 324)
            offsets[R.drawable.reindeer_pinchin0006] = Point(0, 0)
            offsets[R.drawable.elf_pinchin_0009] = Point(500, 990)
            offsets[R.drawable.santa_swipeup0015] = Point(267, 203)
            offsets[R.drawable.snowman_swipeleft0018] = Point(429, 221)
            offsets[R.drawable.reindeer_swipeup0005] = Point(344, 186)
            offsets[R.drawable.reindeer_swipeup0001] = Point(342, 337)
            offsets[R.drawable.santa_tap0003] = Point(270, 435)
            offsets[R.drawable.elf_idle_0020] = Point(435, 438)
            offsets[R.drawable.elf_swipeleft_0018] = Point(435, 441)
            offsets[R.drawable.santa_swipedown0024] = Point(0, 435)
            offsets[R.drawable.snowman_shake0009] = Point(107, 0)
            offsets[R.drawable.santa_pinchout20017] = Point(0, 0)
            offsets[R.drawable.elf_idle_0003] = Point(435, 439)
            offsets[R.drawable.snowman_shake0018] = Point(72, 0)
            offsets[R.drawable.elf_swipeup_0008] = Point(378, 188)
            offsets[R.drawable.reindeer_pinchout0019] = Point(118, 62)
            offsets[R.drawable.snowman_swipeup0019] = Point(376, 133)
            offsets[R.drawable.elf_swiperight_0004] = Point(395, 453)
            offsets[R.drawable.elf_shake_0014] = Point(318, 362)
            offsets[R.drawable.elf_swiperight_0015] = Point(0, 572)
            offsets[R.drawable.snowman_pinchout0008] = Point(307, 532)
            offsets[R.drawable.elf_swiperight_0016] = Point(0, 623)
            offsets[R.drawable.reindeer_swiperight0002] = Point(342, 337)
            offsets[R.drawable.elf_pinchin_0004] = Point(472, 655)
            offsets[R.drawable.elf_swipeleft_0016] = Point(444, 441)
            offsets[R.drawable.snowman_swiperight0002] = Point(139, 221)
            offsets[R.drawable.snowman_swiperight0004] = Point(224, 221)
            offsets[R.drawable.santa_swipe_right20024] = Point(415, 435)
            offsets[R.drawable.reindeer_pinchout0020] = Point(147, 97)
            offsets[R.drawable.santa_swipeup0008] = Point(429, 283)
            offsets[R.drawable.elf_pinchin_0030] = Point(435, 480)
            offsets[R.drawable.snowman_swipeup0015] = Point(253, 21)
            offsets[R.drawable.santa_swipedown0017] = Point(0, 0)
            offsets[R.drawable.elf_pinchin_0032] = Point(435, 445)
            offsets[R.drawable.snowman_swipedown0017] = Point(429, 129)
            offsets[R.drawable.santa_pinchout20005] = Point(0, 0)
            offsets[R.drawable.snowman_swipeleft0014] = Point(429, 221)
            offsets[R.drawable.reindeer_swiperight0011] = Point(26, 1021)
            offsets[R.drawable.reindeer_shake0009] = Point(384, 15)
            offsets[R.drawable.reindeer_swiperight0007] = Point(313, 629)
            offsets[R.drawable.santa_tap0004] = Point(270, 443)
            offsets[R.drawable.reindeer_pinchin0007] = Point(0, 0)
            offsets[R.drawable.santa_swipe_right20012] = Point(426, 350)
            offsets[R.drawable.snowman_pinchin0019] = Point(167, 234)
            offsets[R.drawable.reindeer_shake0017] = Point(384, 14)
            offsets[R.drawable.santa_swipe_right20006] = Point(346, 420)
            offsets[R.drawable.snowman_pinchout0023] = Point(382, 243)
            offsets[R.drawable.elf_shake_0022] = Point(336, 324)
            offsets[R.drawable.santa_swipe_right20018] = Point(415, 389)
            offsets[R.drawable.snowman_swiperight0010] = Point(235, 221)
            offsets[R.drawable.santa_swipe_right20013] = Point(420, 336)
            offsets[R.drawable.snowman_swipeleft0015] = Point(429, 221)
            offsets[R.drawable.elf_idle_0022] = Point(435, 439)
            offsets[R.drawable.santa_shake0007] = Point(257, 475)
            offsets[R.drawable.elf_swiperight_0008] = Point(611, 565)
            offsets[R.drawable.santa_pinchin0020] = Point(235, 505)
            offsets[R.drawable.snowman_swipeleft0017] = Point(429, 221)
            offsets[R.drawable.elf_swipeleft_0017] = Point(422, 440)
            offsets[R.drawable.santa_pinchin0003] = Point(268, 435)
            offsets[R.drawable.snowman_pinchout0004] = Point(377, 390)
            offsets[R.drawable.santa_tap0018] = Point(270, 404)
            offsets[R.drawable.snowman_swipedown0019] = Point(429, 262)
            offsets[R.drawable.santa_idle0004] = Point(415, 432)
            offsets[R.drawable.reindeer_swipeup0004] = Point(342, 197)
            offsets[R.drawable.reindeer_swiperight0020] = Point(383, 352)
            offsets[R.drawable.santa_pinchin0022] = Point(270, 435)
            offsets[R.drawable.snowman_swipeup0018] = Point(214, 71)
            offsets[R.drawable.reindeer_swipeup0002] = Point(342, 321)
            offsets[R.drawable.reindeer_swipeleft0009] = Point(284, 276)
            offsets[R.drawable.santa_idle0047] = Point(415, 435)
            offsets[R.drawable.snowman_swiperight0014] = Point(428, 221)
            offsets[R.drawable.reindeer_shake0012] = Point(384, 14)
            offsets[R.drawable.elf_pinchout_0021] = Point(184, 0)
            offsets[R.drawable.snowman_pinchin0017] = Point(167, 596)
            offsets[R.drawable.santa_swipe_right20019] = Point(415, 435)
            offsets[R.drawable.reindeer_shake0011] = Point(383, 13)
            offsets[R.drawable.santa_tap0009] = Point(269, 567)
            offsets[R.drawable.elf_pinchin_0005] = Point(462, 727)
            offsets[R.drawable.snowman_pinchin0013] = Point(90, 1008)
            offsets[R.drawable.santa_swipeup0011] = Point(429, 221)
            offsets[R.drawable.elf_swipedown_0019] = Point(435, 474)
            offsets[R.drawable.snowman_tap0018] = Point(98, 221)
            offsets[R.drawable.elf_shake_0007] = Point(244, 285)
            offsets[R.drawable.elf_idle_0015] = Point(435, 436)
            offsets[R.drawable.santa_pinchin0008] = Point(111, 178)
            offsets[R.drawable.snowman_idle0008] = Point(429, 217)
            offsets[R.drawable.reindeer_swipedown0022] = Point(354, 384)
            offsets[R.drawable.reindeer_tap0007] = Point(342, 337)
            offsets[R.drawable.elf_swipedown_0013] = Point(397, 628)
            offsets[R.drawable.elf_pinchin_0028] = Point(434, 440)
            offsets[R.drawable.snowman_swipeleft0008] = Point(429, 221)
            offsets[R.drawable.snowman_tap0023] = Point(169, 221)
            offsets[R.drawable.elf_tap_0009] = Point(132, 248)
            offsets[R.drawable.elf_swipedown_0004] = Point(435, 434)
            offsets[R.drawable.santa_shake0004] = Point(204, 478)
            offsets[R.drawable.reindeer_swipedown0002] = Point(344, 344)
            offsets[R.drawable.elf_pinchout_0005] = Point(0, 0)
            offsets[R.drawable.snowman_swipeleft0002] = Point(429, 221)
            offsets[R.drawable.elf_swipedown_0021] = Point(435, 467)
            offsets[R.drawable.reindeer_tap0021] = Point(342, 337)
            offsets[R.drawable.snowman_shake0011] = Point(95, 0)
            offsets[R.drawable.elf_pinchin_0017] = Point(520, 222)
            offsets[R.drawable.santa_shake0018] = Point(393, 420)
            offsets[R.drawable.reindeer_swiperight0004] = Point(348, 337)
            offsets[R.drawable.snowman_swipeleft0012] = Point(429, 221)
            offsets[R.drawable.reindeer_swipeup0009] = Point(210, 38)
            offsets[R.drawable.reindeer_shake0003] = Point(384, 193)
            offsets[R.drawable.santa_swipeup0017] = Point(274, 245)
            offsets[R.drawable.santa_swipeup0009] = Point(429, 271)
        }

        @JvmField
        var ORIG_SIZE = Point(1280, 1280)

        @JvmStatic
        fun getOffsets(@DrawableRes drawableId: Int): Point {
            val p = offsets[drawableId]
            return p ?: EMPTY
        }

        private val EMPTY = Point(0, 0)
    }
}